#!/bin/sh
#compile kernel for rpi4.
#got source from here: git clone --depth=1 --branch rpi-5.10.y https://github.com/raspberrypi/linux
#20210107 first release.
#20210108 very annoying, how do they append "+" onto the version!
#20210113 copy dt files to boot/device-tree

. /etc/DISTRO_SPECS

#20201214 stupid thing, hardcoded...
if [ ! -e /usr/bin/awk ];then
 ln -s /bin/gawk /usr/bin/awk
fi

echo -n "Please type in the kernel version [5.10.4+]: "
read fullkernelver
[ "$fullkernelver" = "" ] && fullkernelver="5.10.4+"
KERNELVER3="`echo -n "$fullkernelver" | rev | cut -f 2-9 -d '.' | rev`" #ex: 5.10
MINORVERSION="`echo -n "$fullkernelver" | rev | cut -f 1 -d '.' | rev`" #ex: 4+

TODAYDATE="`date +%Y%m%d`"

CURDIR="`pwd`"
if [ "$CURDIR" != "/usr/src" ];then
 echo 'This script must be in /usr/src'
 exit
fi
if [ ! -d 3rd-party/filesystem ];then
 echo 'Please download the aufs4-standalone*.tar.gz to 3rd-party/filesystem'
 echo 'and all of the other 3rd-party drivers, in correct subdirectories.'
 exit
fi
if [ ! -d 3rd-party/modems ];then
 echo 'Please download the drivers in 3rd-party/modems.'
 exit
fi
if [ ! -d 3rd-party/wireless ];then
 echo 'Please download the drivers in 3rd-party/wireless'
 exit
fi
if [ ! -f linux-${KERNELVER3}.tar.bz2 ];then
 echo "Please download linux-${KERNELVER3}.tar.bz2"
 exit
fi
if [ ! -f DOTconfig ];then
 echo 'Please download DOTconfig, the kernel configuration file'
 echo 'If you have another file that you want to use, rename it to DOTconfig'
 exit
fi

if [ "$MINORVERSION" != "0" ];then #130220
if [ ! -f patches/patch-${KERNELVER3}.${MINORVERSION}.bz2 ];then
 echo "Please download patch-${KERNELVER3}.${MINORVERSION}.bz2 and other patches, to patches dir"
 exit
fi
fi

rm -rf temp1 2>/dev/null
mkdir temp1

echo
echo "The kernel will identify itself as version"
echo "'${KERNELVER3}.${MINORVERSION}' and the modules will be in /lib/modules/${KERNELVER3}.${MINORVERSION}."
KERNELVERSION=${KERNELVER3}.${MINORVERSION}
echo "...ok, kernel version is '${KERNELVERSION}'"

rm -rf out-k* 2>/dev/null #get rid of earlier builds.
sync

#patch kernel
echo
echo 'Extracting and patching kernel...'
rm -rf linux-${KERNELVER3} 2> /dev/null
rm -rf linux-${KERNELVERSION} 2> /dev/null
sync
tar -jxf linux-${KERNELVER3}.tar.bz2
sync

if [ "$MINORVERSION" != "0" ];then #130220
 echo
 echo "minor version number .${MINORVERSION} patch..."
 cp -f patches/patch-${KERNELVER3}.${MINORVERSION}.bz2 ./
 bunzip2 patch-${KERNELVER3}.${MINORVERSION}.bz2
 sync

 cd linux-${KERNELVER3}
 patch -p1 < ../patch-${KERNELVER3}.${MINORVERSION}
 cd ..
 sync
 rm patch-${KERNELVER3}.${MINORVERSION}
fi

[ "${KERNELVER3}" != "${KERNELVERSION}" ] && mv -f linux-${KERNELVER3} linux-${KERNELVERSION}
ln -snf linux-${KERNELVERSION} linux

#loglevel
echo
if [ -f patches/printk.c.patch.gz ];then
 echo 'loglevel patch...'
 cp -f patches/printk.c.patch.gz ./
 gunzip printk.c.patch.gz
 cd linux-${KERNELVERSION}
 patch -p0 < ../printk.c.patch
 cd ..
 rm printk.c.patch
fi
#141018 K3.16.6, printk patch now in printk.h, previously was printk.c...
if [ -f patches/printk.h.patch.gz ];then
 echo 'loglevel patch...'
 cp -f patches/printk.h.patch.gz ./
 gunzip printk.h.patch.gz
 cd linux-${KERNELVERSION}
 patch -p0 < ../printk.h.patch
 cd ..
 rm printk.h.patch
fi

#vortex86mx cpu
echo
if [ -f patches/vortex86mx.patch.gz ];then
 echo 'vortex86mx cpu patch...'
 cp -f patches/vortex86mx.patch.gz ./
 gunzip vortex86mx.patch.gz
 cd linux-${KERNELVERSION}
 patch -p1 < ../vortex86mx.patch
 cd ..
 rm vortex86mx.patch
fi

#aufs2.1
echo
if [ "`ls 3rd-party/filesystem/aufs2-standalone*.tar.gz 2>/dev/null`" != "" ];then
 echo 'aufs patch...'
 cp -f 3rd-party/filesystem/aufs2-standalone*.tar.gz temp1/aufs.tar.gz
 cd temp1
 tar -zxf aufs.tar.gz
 cd aufs2-standalone
 cp -f aufs2-base.patch ../../
 cp -f aufs2-kbuild.patch ../../
 cp -f aufs2-standalone.patch ../../
 cd ../../linux-${KERNELVERSION}
 patch -p1 < ../aufs2-kbuild.patch
 patch -p1 < ../aufs2-base.patch
 patch -p1 < ../aufs2-standalone.patch
 cp -a -f ../temp1/aufs2-standalone/Documentation ./
 cp -a -f ../temp1/aufs2-standalone/fs ./
 cp -a -f ../temp1/aufs2-standalone/include/linux/aufs_type.h ./include/linux/
 cd ..
 gzip aufs2-kbuild.patch
 gzip aufs2-base.patch
 gzip aufs2-standalone.patch
 mv -f aufs2-kbuild.patch.gz patches/
 mv -f aufs2-base.patch.gz patches/
 mv -f aufs2-standalone.patch.gz patches/
 
 #aufs-allow-sfs-in-branch
 echo
 echo 'aufs-allow-sfs-in-branch patch...'
 cp patches/aufs-allow-sfs.patch.gz ./
 gunzip aufs-allow-sfs.patch.gz
 cd linux-${KERNELVERSION}
 patch -p1 < ../aufs-allow-sfs.patch
 cd ..
 rm aufs-allow-sfs.patch
fi

if [ "`ls 3rd-party/filesystem/aufs3*.tar.gz 2>/dev/null`" != "" ];then
 echo 'aufs patch...'
 cp -f 3rd-party/filesystem/aufs3*.tar.gz temp1/aufs.tar.gz
 cd temp1
 tar -zxf aufs.tar.gz
 DIRNAME="`find -mindepth 1 -maxdepth 1 -type d -name 'aufs3*'`"
 cd $DIRNAME
 cp -f aufs3-base.patch ../../
 cp -f aufs3-kbuild.patch ../../
 cp -f aufs3-standalone.patch ../../
 #cp -f aufs3-loopback.patch ../../
 cp -f aufs3-mmap.patch ../../ #131204
 cd ../../linux-${KERNELVERSION}
 patch -p1 < ../aufs3-kbuild.patch
 patch -p1 < ../aufs3-base.patch
 patch -p1 < ../aufs3-standalone.patch
 #patch -p1 < ../aufs3-loopback.patch
 patch -p1 < ../aufs3-mmap.patch #131204
 cp -a -f ../temp1/$DIRNAME/Documentation ./
 cp -a -f ../temp1/$DIRNAME/fs ./
 cp -a -f ../temp1/$DIRNAME/include/linux/aufs_type.h ./include/linux/ 2>/dev/null #131204 fails.
 [ -d ../temp1/$DIRNAME/include/uapi/linux ] && cp -a -f ../temp1/$DIRNAME/include/uapi/linux/aufs_type.h ./include/uapi/linux/ #130220
 cd ..
 gzip aufs3-kbuild.patch
 gzip aufs3-base.patch
 gzip aufs3-standalone.patch
 gzip aufs3-mmap.patch
 mv -f aufs3-kbuild.patch.gz patches/
 mv -f aufs3-base.patch.gz patches/
 mv -f aufs3-standalone.patch.gz patches/
 mv -f aufs3-mmap.patch.gz patches/
 #mv -f aufs3-loopback.patch.gz patches/
 
 #aufs-allow-sfs-in-branch
 echo
 echo 'aufs-allow-sfs-in-branch patch...'
 cp patches/aufs-allow-sfs.patch.gz ./
 gunzip aufs-allow-sfs.patch.gz
 cd linux-${KERNELVERSION}
 patch -p1 < ../aufs-allow-sfs.patch
 cd ..
 rm aufs-allow-sfs.patch
fi

if [ "`ls 3rd-party/filesystem/aufs4*.tar.gz 2>/dev/null`" != "" ];then
 echo 'aufs patch...'
 cp -f 3rd-party/filesystem/aufs4*.tar.gz temp1/aufs.tar.gz
 cd temp1
 tar -zxf aufs.tar.gz
 DIRNAME="`find -mindepth 1 -maxdepth 1 -type d -name 'aufs4*'`"
 cd $DIRNAME
 cp -f aufs4-base.patch ../../
 cp -f aufs4-kbuild.patch ../../
 cp -f aufs4-standalone.patch ../../
 #cp -f aufs4-loopback.patch ../../
 cp -f aufs4-mmap.patch ../../ #131204
 cd ../../linux-${KERNELVERSION}
 patch -p1 < ../aufs4-kbuild.patch
 patch -p1 < ../aufs4-base.patch
 patch -p1 < ../aufs4-standalone.patch
 #patch -p1 < ../aufs4-loopback.patch
 patch -p1 < ../aufs4-mmap.patch #131204
 cp -a -f ../temp1/$DIRNAME/Documentation ./
 cp -a -f ../temp1/$DIRNAME/fs ./
 cp -a -f ../temp1/$DIRNAME/include/linux/aufs_type.h ./include/linux/ 2>/dev/null #131204 fails.
 [ -d ../temp1/$DIRNAME/include/uapi/linux ] && cp -a -f ../temp1/$DIRNAME/include/uapi/linux/aufs_type.h ./include/uapi/linux/ #130220
 cd ..
 gzip aufs4-kbuild.patch
 gzip aufs4-base.patch
 gzip aufs4-standalone.patch
 gzip aufs4-mmap.patch
 mv -f aufs4-kbuild.patch.gz patches/
 mv -f aufs4-base.patch.gz patches/
 mv -f aufs4-standalone.patch.gz patches/
 mv -f aufs4-mmap.patch.gz patches/
 #mv -f aufs4-loopback.patch.gz patches/
 
 #aufs-allow-sfs-in-branch
 echo
 echo 'aufs-allow-sfs-in-branch patch...'
 cp patches/aufs-allow-sfs.patch.gz ./
 gunzip aufs-allow-sfs.patch.gz
 cd linux-${KERNELVERSION}
 patch -p1 < ../aufs-allow-sfs.patch
 cd ..
 rm aufs-allow-sfs.patch
fi

#20190702 aufs5
#191201 fix for 5.4 kernel. no, fixed aufs5-standalone patch.
#       no, aufs5-standalone patch is not needed when driver builtin...
if [ "`ls 3rd-party/filesystem/aufs5*.tar.gz 2>/dev/null`" != "" ];then
 echo 'aufs patch...'
 cp -f 3rd-party/filesystem/aufs5*.tar.gz temp1/aufs.tar.gz
 cd temp1
 tar -zxf aufs.tar.gz
 DIRNAME="`find -mindepth 1 -maxdepth 1 -type d -name 'aufs5*'`"
 cd $DIRNAME
 cp -f aufs5-base.patch ../../
 cp -f aufs5-kbuild.patch ../../
 #if vercmp ${KERNELVER3} lt 5.4;then cp -f aufs5-standalone.patch ../../ ; fi
 #cp -f aufs5-standalone.patch ../../
 #cp -f aufs5-loopback.patch ../../
 cp -f aufs5-mmap.patch ../../ #131204
 cd ../../linux-${KERNELVERSION}
 patch -p1 < ../aufs5-kbuild.patch
 patch -p1 < ../aufs5-base.patch
 #if vercmp ${KERNELVER3} lt 5.4;then patch -p1 < ../aufs5-standalone.patch ; fi
 #patch -p1 < ../aufs5-standalone.patch
 #patch -p1 < ../aufs5-loopback.patch
 patch -p1 < ../aufs5-mmap.patch #131204
 cp -a -f ../temp1/$DIRNAME/Documentation ./
 cp -a -f ../temp1/$DIRNAME/fs ./
 cp -a -f ../temp1/$DIRNAME/include/linux/aufs_type.h ./include/linux/ 2>/dev/null #131204 fails.
 [ -d ../temp1/$DIRNAME/include/uapi/linux ] && cp -a -f ../temp1/$DIRNAME/include/uapi/linux/aufs_type.h ./include/uapi/linux/ #130220
 cd ..
 gzip aufs5-kbuild.patch
 gzip aufs5-base.patch
 #if vercmp ${KERNELVER3} lt 5.4;then gzip aufs5-standalone.patch ; fi
 #gzip aufs5-standalone.patch
 gzip aufs5-mmap.patch
 mv -f aufs5-kbuild.patch.gz patches/
 mv -f aufs5-base.patch.gz patches/
 #if vercmp ${KERNELVER3} lt 5.4;then mv -f aufs5-standalone.patch.gz patches/ ; fi
 #mv -f aufs5-standalone.patch.gz patches/
 mv -f aufs5-mmap.patch.gz patches/
 #mv -f aufs5-loopback.patch.gz patches/
 
 #aufs-allow-sfs-in-branch
 echo
 echo 'aufs-allow-sfs-in-branch patch...'
 cp patches/aufs-allow-sfs.patch.gz ./
 gunzip aufs-allow-sfs.patch.gz
 cd linux-${KERNELVERSION}
 patch -p1 < ../aufs-allow-sfs.patch
 cd ..
 rm aufs-allow-sfs.patch
fi



#commoncap security
echo
if [ -f patches/commoncap-symbol.patch.gz ];then
 echo 'commoncap symbol export patch...'
 cp patches/commoncap-symbol.patch.gz ./
 gunzip commoncap-symbol.patch.gz
 cd linux-${KERNELVERSION}
 patch -p1 < ../commoncap-symbol.patch
 cd ..
 rm commoncap-symbol.patch
fi

#161115
if [ -f patches/01-dm-v5-1-3.patch.gz ];then
 echo 'device-mapper patches...'
 cp -f patches/01-dm-v5-1-3.patch.gz ./
 gunzip 01-dm-v5-1-3.patch.gz
 cd linux-${KERNELVERSION}
 patch -p1 < ../01-dm-v5-1-3.patch
 cd ..
 rm -f 01-dm-v5-1-3.patch
 cp -f patches/02-dm-v5-2-3.patch.gz ./
 gunzip 02-dm-v5-2-3.patch.gz
 cd linux-${KERNELVERSION}
 patch -p1 < ../02-dm-v5-2-3.patch
 cd ..
 rm -f 02-dm-v5-2-3.patch
 cp -f patches/03-dm-v5-3-3.patch.gz ./
 gunzip 03-dm-v5-3-3.patch.gz
 cd linux-${KERNELVERSION}
 patch -p1 < ../03-dm-v5-3-3.patch
 cd ..
 rm -f 03-dm-v5-3-3.patch
fi

#usb-storage
if [ -f patches/usb-storage.patch.gz ];then #170304
 if vercmp ${KERNELVERSION} ge 2.6.33;then
  echo
  echo 'usb-storage patch...'
  cp patches/usb-storage.patch.gz ./
  gunzip usb-storage.patch.gz
  cd linux-${KERNELVERSION}
  if vercmp ${KERNELVERSION} ge 3.0.25;then
   patch -p1 < ../usb-storage.patch
  else
   patch -p0 < ../usb-storage.patch
  fi
  cd ..
  rm usb-storage.patch
 fi
fi

#unionfs
if [ "`ls patches/unionfs*.gz 2>/dev/null`" != "" ];then
 cp -f patches/unionfs*.gz unionfs.patch.gz
 gunzip unionfs.patch.gz
 cd linux-${KERNELVERSION}
 patch -p1 < ../unionfs.patch
 cd ..
 rm unionfs.patch
fi

#180520
if [ -f patches/cap_sys_mount-1.patch.gz ];then
 echo
 echo "cap_sys_mount patch..."
 cp -f patches/cap_sys_mount-1.patch.gz ./
 gunzip cap_sys_mount-1.patch.gz
 cp -f patches/cap_sys_mount-2.patch.gz ./
 gunzip cap_sys_mount-2.patch.gz
 cd linux-${KERNELVERSION}
 patch -p1 < ../cap_sys_mount-1.patch
 patch -p1 < ../cap_sys_mount-2.patch
 cd ..
 rm cap_sys_mount-1.patch
 rm cap_sys_mount-2.patch
fi

#200109
if [ -f patches/btusb-Enablement-of-HCI_QUIRK_BROKEN_STORED_LINK_KEY-quirk.patch ];then
 echo
 echo "CSR 4.0 dongle chines clone patch..."
 cd linux-${KERNELVERSION}
 patch -p1 < ../patches/btusb-Enablement-of-HCI_QUIRK_BROKEN_STORED_LINK_KEY-quirk.patch
 cd ..
fi

#create tarball of patched source
sync
echo
echo 'Creating kernel patched source tarball...'
rm -f linux-${KERNELVERSION}-src-patched.tar.bz2 2>/dev/null
tar -c -f linux-${KERNELVERSION}-src-patched.tar linux-${KERNELVERSION}/
bzip2 linux-${KERNELVERSION}-src-patched.tar
sync

#compile kernel
echo
echo -n 'ENTER to compile kernel: '
read goforit
cd linux-${KERNELVERSION}
make clean
make mrproper
cp -f ../DOTconfig .config
make menuconfig
sync
sleep 1
cp -f .config DOTconfig-${KERNELVERSION}
cp -f DOTconfig-${KERNELVERSION} ../

##rpi source has a "+" appended to the version, remove it...
#echo "Deleting + off end of version number..."
#sed -i -e 's%\+$%%' linux-${KERNELVERSION}/include/config/kernel.release

echo -n 'ENTER to compile kernel: '
read goforit

#make
make ARCH=arm64 Image modules dtbs
if [ $? -ne 0 ];then
 echo "FAILED: make ARCH=arm64 Image modules dtbs"
 echo -n "Fix, if possible, then press ENTER to try again: "
 read tryagain
 make ARCH=arm64 Image modules dtbs
 if [ $? -ne 0 ];then
  echo "FAILED: make ARCH=arm64 Image modules dtbs"
  echo -n "Fix, if possible, then press ENTER to try again: "
  read tryagain
  make ARCH=arm64 Image modules dtbs
  if [ $? -ne 0 ];then
   echo "FAILED: make ARCH=arm64 Image modules dtbs"
   echo "EXITING"
   exit
  fi
 fi
fi
sync

#place to send everything...
rm -rf /usr/src/out-k${KERNELVERSION} 2> /dev/null
mkdir /usr/src/out-k${KERNELVERSION}


#install kernel
echo
echo -n "ENTER to install kernel: "
read goforit
echo
echo "Installing modules..."
rm -rf /lib/modules/${KERNELVERSION} 2> /dev/null
make modules_install
sync

echo "Creating headers tarball in /usr/src/out-k${KERNELVERSION}..."
make headers_install
sync
mkdir -p /usr/src/out-k${KERNELVERSION}/linux_headers-${KERNELVERSION}/usr/include
cp -a -f usr/include/* ../out-k${KERNELVERSION}/linux_headers-${KERNELVERSION}/usr/include/
sync

#120325 turn headers into a pet...
#linux_headers_DEV-2.6.32-40|linux_headers_DEV|2.6.32-40||BuildingBlock|4236K||linux_headers_DEV-2.6.32-40.pet||header files for 2.6.32.40 kernel||||
HDRSIZE=$(du -s -k ../out-k${KERNELVERSION}/linux_headers-${KERNELVERSION} | cut -f 1)
echo "linux_headers-${KERNELVERSION}|linux_headers|${KERNELVERSION}||BuildingBlock|${HDRSIZE}K||linux_headers-${KERNELVERSION}.pet||header files for ${KERNELVERSION} kernel||||" > ../out-k${KERNELVERSION}/linux_headers-${KERNELVERSION}/pet.specs


echo "Creating tarball of modules..."
cp -a -f /lib/modules/${KERNELVERSION} ../out-k${KERNELVERSION}/

echo "Copying DOTconfig-${KERNELVERSION}, System.map, vmlinuz..."
cp -f DOTconfig-${KERNELVERSION} ../out-k${KERNELVERSION}/
cp -f System.map ../out-k${KERNELVERSION}/
cp -f modules.order ../out-k${KERNELVERSION}/
cp -f modules.builtin ../out-k${KERNELVERSION}/
cp -f arch/arm64/boot/Image ../out-k${KERNELVERSION}/kernel8.img
sync

echo "Copying device tree..."
mkdir -p ../out-k${KERNELVERSION}/device-tree/boot/overlays
cp arch/arm64/boot/dts/broadcom/*.dtb ../out-k${KERNELVERSION}/device-tree/boot/
cp arch/arm/boot/dts/overlays/*.dtb* ../out-k${KERNELVERSION}/device-tree/boot/overlays/
cp arch/arm/boot/dts/overlays/README ../out-k${KERNELVERSION}/device-tree/boot/overlays/
sync

echo "Creating linux_headers-${KERNELVERSION}.pet ..."
echo -n "ENTER to continue:"
read keepgoing
cd ../out-k${KERNELVERSION}
#dir2tgz firmware/
dir2tgz linux_headers-${KERNELVERSION}
sync
tgz2pet linux_headers-${KERNELVERSION}.tar.gz
sync

cp -a ../patches ./
cp -a ../3rd-party ./
mv -f ../DOTconfig ../DOTconfig-PREVIOUS
cp -f DOTconfig-${KERNELVERSION} ../DOTconfig
mv -f ../linux-${KERNELVERSION}-src-patched.tar.bz2 ./
sync

echo "Creating kernel source sfs..."
echo -n "ENTER to continue:"
read keepgoing
cd ../linux-${KERNELVERSION}
make clean
make prepare
sync
cd ..
rm -rf kernel_${KERNELVERSION}-p1_src 2> /dev/null
mkdir kernel_${KERNELVERSION}-p1_src
mkdir -p kernel_${KERNELVERSION}-p1_src/usr/src
mkdir -p kernel_${KERNELVERSION}-p1_src/lib/modules/${KERNELVERSION}
cp -a -f linux-${KERNELVERSION} kernel_${KERNELVERSION}-p1_src/usr/src/
ln -s linux-${KERNELVERSION} kernel_${KERNELVERSION}-p1_src/usr/src/linux
ln -s /usr/src/linux-${KERNELVERSION} kernel_${KERNELVERSION}-p1_src/lib/modules/${KERNELVERSION}/build
ln -s /usr/src/linux-${KERNELVERSION} kernel_${KERNELVERSION}-p1_src/lib/modules/${KERNELVERSION}/source

echo "Creating meta-data for kernel_${KERNELVERSION}-p1_src.sfs ..."
SIZEK="$(du -s -k kernel_${KERNELVERSION}-p1_src | cut -f 1)"
echo "#generated by 3package.sh:
DB_pkgname='kernel_${KERNELVERSION}-p1'
DB_nameonly='kernel'
DB_version='${KERNELVERSION}'
DB_revision='p1'
DB_arch='src'
DB_categories='Utility'
DB_size='${SIZEK}'
DB_fullfilename='kernel_${KERNELVERSION}-p1_src.sfs'
DB_dependencies='devx,easy'
DB_description='Linux kernel ${KERNELVERSION} source'
DB_description_long='This is the kernel source. In a layered filesystem with the devx and easy SFS files underneath, the kernel may be recompiled, or extra modules compiled.'
DB_compileddistro='${DISTRO_BINARY_COMPAT}'
DB_compiledrelease='${DISTRO_COMPAT_VERSION}'
DB_path='easyos/${DISTRO_BINARY_COMPAT}/${DISTRO_COMPAT_VERSION}'
DB_apps='kernel'
DB_icons='kernel'
DB_install='individual'
DB_hash=''" > out-k${KERNELVERSION}/kernel_${KERNELVERSION}-p1_src.specs

mkdir -p kernel_${KERNELVERSION}-p1_src/.control
cp -a -f out-k${KERNELVERSION}/kernel_${KERNELVERSION}-p1_src.specs kernel_${KERNELVERSION}-p1_src/.control/kernel.specs

mkdir -p kernel_${KERNELVERSION}-p1_src/usr/share/pixmaps
cp -f kernel48.png kernel_${KERNELVERSION}-p1_src/usr/share/pixmaps/
cp -f kernel48.png kernel_${KERNELVERSION}-p1_src/usr/share/pixmaps/kernel.png
cp -f ec-kernel48.png kernel_${KERNELVERSION}-p1_src/usr/share/pixmaps/
cp -f kernel48.png out-k${KERNELVERSION}/kernel.png
#dummy .desktop...
mkdir -p kernel_${KERNELVERSION}-p1_src/usr/share/applications
echo "[Desktop Entry]
NoDisplay=true
Name=kernel
Exec=ec-chroot-kernel
Icon=container48.png
Categories=X-Utility" > kernel_${KERNELVERSION}-p1_src/usr/share/applications/kernel.desktop
#run script...
mkdir -p kernel_${KERNELVERSION}-p1_src/usr/sbin
echo "#!/bin/sh
empty -f ec-chroot kernel sakura" > kernel_${KERNELVERSION}-p1_src/usr/sbin/ec-chroot-kernel
chmod 755 kernel_${KERNELVERSION}-p1_src/usr/sbin/ec-chroot-kernel
#***NOTICE*** haven't created .control/kernel.configuration
[ -f out-k${KERNELVERSION}/kernel_${KERNELVERSION}-p1_src.sfs ] && rm -f out-k${KERNELVERSION}/kernel_${KERNELVERSION}-p1_src.sfs
sync
mksquashfs4 kernel_${KERNELVERSION}-p1_src out-k${KERNELVERSION}/kernel_${KERNELVERSION}-p1_src.sfs
sync
chmod 644 out-k${KERNELVERSION}/kernel_${KERNELVERSION}-p1_src.sfs
HASH="$(sha256sum out-k${KERNELVERSION}/kernel_${KERNELVERSION}-p1_src.sfs | cut -f 1 -d ' ')"
sed -i -e "s%^DB_hash=.*%DB_hash='${HASH}'%" out-k${KERNELVERSION}/kernel_${KERNELVERSION}-p1_src.specs
sync

cd out-k${KERNELVERSION}
echo "Creating kernel PET..."
echo
echo "The PET package will be named something like"
echo "'linux_kernel-${KERNELVERSION}-pae-i686-w5.pet'"
echo -n "Type a string for the 'pae-i686-w5' part: "
read PETPOSTSTR
rm -rf linux_kernel-${KERNELVERSION}-${PETPOSTSTR} 2>/dev/null
mkdir linux_kernel-${KERNELVERSION}-${PETPOSTSTR}
mkdir linux_kernel-${KERNELVERSION}-${PETPOSTSTR}/boot
mkdir -p linux_kernel-${KERNELVERSION}-${PETPOSTSTR}/etc/modules
mkdir -p linux_kernel-${KERNELVERSION}-${PETPOSTSTR}/lib/modules
mkdir linux_kernel-${KERNELVERSION}-${PETPOSTSTR}/lib/firmware

cp -f System.map linux_kernel-${KERNELVERSION}-${PETPOSTSTR}/boot/
cp -f kernel8.img linux_kernel-${KERNELVERSION}-${PETPOSTSTR}/boot/
#cp -f -a device-tree/boot/* linux_kernel-${KERNELVERSION}-${PETPOSTSTR}/boot/
cp -f -a device-tree/boot linux_kernel-${KERNELVERSION}-${PETPOSTSTR}/boot/device-tree
cp -f DOTconfig-${KERNELVERSION} linux_kernel-${KERNELVERSION}-${PETPOSTSTR}/etc/modules/
cp -f modules.builtin linux_kernel-${KERNELVERSION}-${PETPOSTSTR}/etc/modules/
cp -f modules.order linux_kernel-${KERNELVERSION}-${PETPOSTSTR}/etc/modules/
sync

cp -a ${KERNELVERSION} linux_kernel-${KERNELVERSION}-${PETPOSTSTR}/lib/modules/
rm -f linux_kernel-${KERNELVERSION}-${PETPOSTSTR}/lib/modules/${KERNELVERSION}/build
rm -f linux_kernel-${KERNELVERSION}-${PETPOSTSTR}/lib/modules/${KERNELVERSION}/source

DB_size="$(du -k -s linux_kernel-${KERNELVERSION}-${PETPOSTSTR} | cut -f 1)"
echo "linux_kernel-${KERNELVERSION}-${PETPOSTSTR}|linux_kernel|${KERNELVERSION}-${PETPOSTSTR}||BuildingBlock|${DB_size}K||linux_kernel-${KERNELVERSION}-${PETPOSTSTR}.pet||Linux kernel ${KERNELVERSION} compiled in ${DISTRO_NAME} version ${DISTRO_VERSION}|${DISTRO_BINARY_COMPAT}|${DISTRO_COMPAT_VERSION}||" > linux_kernel-${KERNELVERSION}-${PETPOSTSTR}/pet.specs
sync

dir2tgz linux_kernel-${KERNELVERSION}-${PETPOSTSTR}
sync
tgz2pet linux_kernel-${KERNELVERSION}-${PETPOSTSTR}.tar.gz
sync

echo "Finished"
###END###
